#!/usr/bin/env python
# -*- coding: utf-8  -*-
################################################################################
#
#  Rattail -- Retail Software Framework
#  Copyright © 2010-2012 Lance Edgar
#
#  This file is part of Rattail.
#
#  Rattail is free software: you can redistribute it and/or modify it under the
#  terms of the GNU Affero General Public License as published by the Free
#  Software Foundation, either version 3 of the License, or (at your option)
#  any later version.
#
#  Rattail is distributed in the hope that it will be useful, but WITHOUT ANY
#  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
#  FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for
#  more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with Rattail.  If not, see <http://www.gnu.org/licenses/>.
#
################################################################################

"""
``rattail.pyramid.views.customergroups`` -- CustomerGroup Views
"""

from edbob.pyramid.views import SearchableAlchemyGridView, CrudView

import rattail


class CustomerGroupsGrid(SearchableAlchemyGridView):

    mapped_class = rattail.CustomerGroup
    config_prefix = 'customer_groups'
    sort = 'name'

    def filter_map(self):
        return self.make_filter_map(ilike=['name'])

    def filter_config(self):
        return self.make_filter_config(
            include_filter_name=True,
            filter_type_name='lk')

    def sort_map(self):
        return self.make_sort_map('id', 'name')

    def grid(self):
        g = self.make_grid()
        g.configure(
            include=[
                g.id.label("ID"),
                g.name,
                ],
            readonly=True)
        return g


class CustomerGroupCrud(CrudView):

    mapped_class = rattail.CustomerGroup
    home_route = 'customer_groups'
    pretty_name = "Customer Group"

    def fieldset(self, model):
        fs = self.make_fieldset(model)
        fs.configure(
            include=[
                fs.id.label("ID"),
                fs.name,
                ])
        return fs


def includeme(config):

    config.add_route('customer_groups', '/customer-groups')
    config.add_view(CustomerGroupsGrid, route_name='customer_groups',
                    renderer='/customer_groups/index.mako',
                    permission='customer_groups.list')

    config.add_route('customer_group.read', '/customer-groups/{uuid}')
    config.add_view(CustomerGroupCrud, attr='read', route_name='customer_group.read',
                    renderer='/customer_groups/crud.mako',
                    permission='customer_groups.read')
