#!/usr/bin/env python

"""
``dtail.views.reports`` -- Report Views
"""

import os
import os.path
import re

from mako.template import Template

from pyramid.response import Response

import edbob
from edbob.pyramid import Session

import rattail


def ordering_report(request):
    """
    This is the "Ordering Worksheet" report.
    """

    if request.params.get('vendor'):
        vendor = Session.query(rattail.Vendor).get(request.params['vendor'])
        if vendor:
            departments = []
            uuids = request.params.get('departments')
            if uuids:
                for uuid in uuids.split(','):
                    dept = Session.query(rattail.Department).get(uuid)
                    if dept:
                        departments.append(dept)
            body = write_ordering_worksheet(vendor, departments)
            response = Response(content_type='text/html')
            response.headers['Content-Length'] = len(body)
            response.headers['Content-Disposition'] = 'attachment; filename=ordering.html'
            response.body = body
            return response
    return {}


def write_ordering_worksheet(vendor, departments):
    """
    Rendering engine for the ordering worksheet report.
    """

    q = Session.query(rattail.ProductCost)
    q = q.join(rattail.Product)
    q = q.filter(rattail.ProductCost.vendor == vendor)
    q = q.filter(rattail.Product.department_uuid.in_([x.uuid for x in departments]))

    costs = {}
    for cost in q:
        dept = cost.product.department
        subdept = cost.product.subdepartment
        costs.setdefault(dept, {})
        costs[dept].setdefault(subdept, [])
        costs[dept][subdept].append(cost)

    plu_upc_pattern = re.compile(r'^0000000(\d{5})$')
    weighted_upc_pattern = re.compile(r'^02(\d{5})00000$')

    def get_upc(prod):
        upc = '%012u' % prod.upc
        m = plu_upc_pattern.match(upc)
        if m:
            return str(int(m.group(1)))
        m = weighted_upc_pattern.match(upc)
        if m:
            return str(int(m.group(1)))
        return upc

    now = edbob.local_time()
    data = dict(
        vendor=vendor,
        costs=costs,
        date=now.strftime('%a %d %b %Y'),
        time=now.strftime('%I:%M %p'),
        get_upc=get_upc,
        rattail=rattail,
        )

    report = os.path.join(os.path.dirname(__file__), os.pardir, 'reports', 'ordering_worksheet.mako')
    report = os.path.abspath(report)
    template = Template(filename=report, disable_unicode=True)
    return template.render(**data)


def includeme(config):
    config.add_route('reports.ordering', '/reports/ordering')
    config.add_view(ordering_report, route_name='reports.ordering', renderer='/reports/ordering.mako')
